@@ -67,7 +67,7 @@ is_regular_grid <- function(xy, digits = 6) {
   if (q > 0) {
     cli::cli_abort(paste(
       "x cell sizes are not regular. Try with a lower",
-      crayon::blue("`digit`"),
+      cli::col_blue("`digit`"),
       "value."
     ))
   }
@@ -85,7 +85,7 @@ is_regular_grid <- function(xy, digits = 6) {
   if (q > 0) {
     cli::cli_abort(paste(
       "y cell sizes are not regular. Try with a lower",
-      crayon::blue("`digit`"),
+      cli::col_blue("`digit`"),
       "value."
     ))
   }
