@@ -19,7 +19,7 @@ test_that("SpatRaster mutate and check names", {
   names(spatrast) <- c("a", "a", "b")
 
 
-  fixed_names <- dplyr::mutate(spatrast, b2 = a + 100)
+  expect_snapshot(fixed_names <- dplyr::mutate(spatrast, b2 = a + 100))
 
   all_eq <- all(names(fixed_names) == make.names(c(
     names(spatrast),
@@ -33,7 +33,9 @@ test_that("SpatRaster mutate and check names", {
 
   # Same with layer names as x,y
   names(spatrast) <- c("x", "x", "y")
-  fixed_names2 <- dplyr::mutate(spatrast, b2 = x.1 + x.2 + y.1)
+  expect_snapshot(fixed_names2 <- dplyr::mutate(spatrast,
+    b2 = x.1 + x.2 + y.1
+  ))
 
   all_eq <- all(names(fixed_names2) == make.names(
     c(
@@ -54,8 +56,7 @@ test_that("SpatVector", {
   f <- system.file("extdata/cyl.gpkg", package = "tidyterra")
   v <- terra::vect(f)
 
-  mutated <- v %>%
-    mutate(cpro2 = paste0(cpro, "-CyL"))
+  mutated <- mutate(v, cpro2 = paste0(cpro, "-CyL"))
 
   expect_s4_class(mutated, "SpatVector")
   expect_gt(ncol(mutated), ncol(v))
@@ -64,3 +65,17 @@ test_that("SpatVector", {
     paste0(v$cpro, "-CyL")
   )
 })
+
+
+test_that("mutate preserves grouping", {
+  df <- tibble::tibble(x = 1:2, y = 2)
+  df <- as_spatvector(df, geom = c("x", "y"), keepgeom = TRUE)
+  gf <- group_by(df, x)
+
+  out <- mutate(gf, x = 1)
+  expect_equal(group_vars(out), "x")
+  expect_equal(nrow(group_data(out)), 1)
+
+  out <- mutate(gf, z = 1)
+  expect_equal(group_data(out), group_data(gf))
+})
